==> ecCodes-2.34.1_0%2Bgfortran.darwin_20.x86_64.tbz2: opt/local/include/eccodes_ecbuild_config.h <==
/*
 * (C) Copyright 2011- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

#ifndef ECCODES_ecbuild_config_h
#define ECCODES_ecbuild_config_h

/* ecbuild info */

#ifndef ECBUILD_VERSION_STR
#define ECBUILD_VERSION_STR "3.8.2"
#endif
#ifndef ECBUILD_VERSION
#define ECBUILD_VERSION "3.8.2"
#endif
#ifndef ECBUILD_MACROS_DIR
#define ECBUILD_MACROS_DIR  "/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_science_ecCodes/ecCodes/work/eccodes-2.34.1-Source/cmake"
#endif

/* config info */

#define ECCODES_OS_NAME          "Darwin-20.6.0"
#define ECCODES_OS_BITS          64
#define ECCODES_OS_BITS_STR      "64"
#define ECCODES_OS_STR           "macosx.64"
#define ECCODES_OS_VERSION       "20.6.0"
#define ECCODES_SYS_PROCESSOR    "x86_64"

#define ECCODES_BUILD_TIMESTAMP  "20240227023410"
#define ECCODES_BUILD_TYPE       "Release"

#define ECCODES_C_COMPILER_ID      "AppleClang"
#define ECCODES_C_COMPILER_VERSION "13.0.0.13000029"

#define ECCODES_CXX_COMPILER_ID      "AppleClang"
#define ECCODES_CXX_COMPILER_VERSION "13.0.0.13000029"

#define ECCODES_C_COMPILER       "/usr/bin/clang"
#define ECCODES_C_FLAGS          "-pipe -Os -DNDEBUG -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX11.sdk -pipe -O3 -DNDEBUG"

#define ECCODES_CXX_COMPILER     "/usr/bin/clang++"
#define ECCODES_CXX_FLAGS        "-pipe -Os -DNDEBUG -I/opt/local/include -stdlib=libc++ -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX11.sdk -pipe -Wno-write-strings -Wno-deprecated -O3 -DNDEBUG"

/* Needed for finding per package config files */

#define ECCODES_INSTALL_DIR       "/opt/local"
#define ECCODES_INSTALL_BIN_DIR   "/opt/local/bin"
#define ECCODES_INSTALL_LIB_DIR   "/opt/local/lib"
#define ECCODES_INSTALL_DATA_DIR  "/opt/local/share/eccodes"

#define ECCODES_DEVELOPER_SRC_DIR "/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_science_ecCodes/ecCodes/work/eccodes-2.34.1-Source"
#define ECCODES_DEVELOPER_BIN_DIR "/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_science_ecCodes/ecCodes/work/build"

/* Fortran support */

#if 1

#define ECCODES_Fortran_COMPILER_ID      "GNU"
#define ECCODES_Fortran_COMPILER_VERSION "13.2.0"

#define ECCODES_Fortran_COMPILER "/opt/local/bin/gfortran-mp-13"
#define ECCODES_Fortran_FLAGS    "-pipe -Os -fallow-argument-mismatch -m64 -O3 -DNDEBUG -funroll-all-loops -finline-functions"

#endif

#endif /* ECCODES_ecbuild_config_h */

==> ecCodes-2.35.0_0%2Bgfortran.darwin_20.x86_64.tbz2: opt/local/include/eccodes_ecbuild_config.h <==
/*
 * (C) Copyright 2011- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

#ifndef ECCODES_ecbuild_config_h
#define ECCODES_ecbuild_config_h

/* ecbuild info */

#ifndef ECBUILD_VERSION_STR
#define ECBUILD_VERSION_STR "3.8.3"
#endif
#ifndef ECBUILD_VERSION
#define ECBUILD_VERSION "3.8.3"
#endif
#ifndef ECBUILD_MACROS_DIR
#define ECBUILD_MACROS_DIR  "/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_science_ecCodes/ecCodes/work/eccodes-2.35.0-Source/cmake"
#endif

/* config info */

#define ECCODES_OS_NAME          "Darwin-20.6.0"
#define ECCODES_OS_BITS          64
#define ECCODES_OS_BITS_STR      "64"
#define ECCODES_OS_STR           "macosx.64"
#define ECCODES_OS_VERSION       "20.6.0"
#define ECCODES_SYS_PROCESSOR    "x86_64"

#define ECCODES_BUILD_TIMESTAMP  "20240412113358"
#define ECCODES_BUILD_TYPE       "Release"

#define ECCODES_C_COMPILER_ID      "AppleClang"
#define ECCODES_C_COMPILER_VERSION "13.0.0.13000029"

#define ECCODES_CXX_COMPILER_ID      "AppleClang"
#define ECCODES_CXX_COMPILER_VERSION "13.0.0.13000029"

#define ECCODES_C_COMPILER       "/usr/bin/clang"
#define ECCODES_C_FLAGS          "-pipe -Os -DNDEBUG -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX11.sdk -pipe -O3 -DNDEBUG"

#define ECCODES_CXX_COMPILER     "/usr/bin/clang++"
#define ECCODES_CXX_FLAGS        "-pipe -Os -DNDEBUG -I/opt/local/include -stdlib=libc++ -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX11.sdk -pipe -O3 -DNDEBUG"

/* Needed for finding per package config files */

#define ECCODES_INSTALL_DIR       "/opt/local"
#define ECCODES_INSTALL_BIN_DIR   "/opt/local/bin"
#define ECCODES_INSTALL_LIB_DIR   "/opt/local/lib"
#define ECCODES_INSTALL_DATA_DIR  "/opt/local/share/eccodes"

#define ECCODES_DEVELOPER_SRC_DIR "/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_science_ecCodes/ecCodes/work/eccodes-2.35.0-Source"
#define ECCODES_DEVELOPER_BIN_DIR "/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_science_ecCodes/ecCodes/work/build"

/* Fortran support */

#if 1

#define ECCODES_Fortran_COMPILER_ID      "GNU"
#define ECCODES_Fortran_COMPILER_VERSION "13.2.0"

#define ECCODES_Fortran_COMPILER "/opt/local/bin/gfortran-mp-13"
#define ECCODES_Fortran_FLAGS    "-pipe -Os -fallow-argument-mismatch -m64 -O3 -DNDEBUG -funroll-all-loops -finline-functions"

#endif

#endif /* ECCODES_ecbuild_config_h */
